@@ -203,9 +203,9 @@ class SendGrid(object):
         return self.call('sendip', 'add', dict(task="append", **fields))
     def activate_app(self, user, name):
         return self.call('apps', 'activate', dict(task="activate", user=user, name=name))
-    def customize_app(self, user, name, settings):
+    def customize_app(self, user, name, **settings):
         return self.call('apps', 'customize',
-            dict(task="setup", user=user, name=name, settings=settings))
+            dict(task="setup", user=user, name=name, **settings))
 
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
